@@ -1,6 +1,6 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.0.19'
+__version__ = '0.0.20'
 __all__ = [
     'main',
     'DatClass',
@@ -160,6 +160,8 @@ def merge_list_dict(list_dict: List[dict]) -> Dict:
         for k, v in i.items():
             if k not in d:
                 d[k] = v
+            elif d[k] and isinstance(v, dict):
+                d[k] = merge_list_dict([d[k], v])
             elif not d[k] and v:
                 d[k] = v
     return d
